@@ -345,6 +345,10 @@ def aggressive_artifact_removal(text):
             if patterns.is_citation_or_footnote(full_match):
                 continue
 
+            # Preserve stage directions (keep brackets for stage directions)
+            if patterns.is_stage_direction(full_match):
+                continue
+
             # Empty brackets - remove entirely
             if not inner.strip():
                 line = line[:start] + line[end:]
@@ -374,11 +378,100 @@ def find_content_start(text):
     """Find where narrative begins by looking for first Part/Act/Chapter markers."""
     lines = text.split('\n')
 
-    # First priority: Look for explicit chapter/part/act markers
+    # First priority: Look for strong narrative opening phrases
+    # These should be at the START of the line and be EARLY in the document
+    # We collect ALL matches and choose the earliest one that looks legitimate
+    narrative_openings = [
+        ('in the beginning', True),  # (pattern, requires_word_boundary)
+        ('it was', True),
+        ('once upon a time', False),
+        ('the year was', False),
+        ('it is a truth', False),  # Pride and Prejudice
+        ('when ', True),  # "when i was", "when he was", "when she was", etc.
+        ('there was', True),
+        ('there were', True),
+        ('the ', True),  # Very common: "The amber light", "The boy", etc.
+        ('listen.', False),  # Common literary opening
+        ('listen,', False),
+    ]
+
+    # Collect all potential narrative starts
+    potential_starts = []
+
+    # Find last frontmatter marker (copyright, domain watermarks, etc.)
+    last_frontmatter_idx = 0
+    for i, line in enumerate(lines[:min(200, len(lines))]):  # Only check first 200 lines
+        stripped = line.strip().lower()
+
+        # Check for domain watermarks (e.g., anysite.com)
+        if patterns.DOMAIN_WATERMARK.search(stripped):
+            last_frontmatter_idx = i
+            continue
+
+        # Common frontmatter markers
+        if any(marker in stripped for marker in ['copyright', 'isbn', 'published', 'reserved', 'table of contents', 'dedication']):
+            last_frontmatter_idx = i
+
     for i, line in enumerate(lines):
-        if patterns.matches_chapter_pattern(line):
-            # Found first chapter/part/act, start here
-            return i
+        stripped = line.strip()
+        lower = stripped.lower()
+
+        # Skip if before last frontmatter marker + 2 lines
+        if i < last_frontmatter_idx + 2:
+            continue
+
+        # Check for character name followed by narrative (literary fiction pattern)
+        # Example: "Sir Arthur George Jennings" followed by "Listen."
+        if i > 0 and len(stripped) > 3 and len(stripped) < 50:
+            # Check if this looks like a character name
+            words = stripped.split()
+            if (len(words) >= 2 and
+                all(w[0].isupper() for w in words if len(w) > 0) and
+                not any(kw in lower for kw in ['chapter', 'part', 'book', 'contents', 'copyright', 'dedication'])):
+                # Check if next line starts narrative
+                if i + 1 < len(lines):
+                    next_line = lines[i + 1].strip().lower()
+                    if any(next_line.startswith(opening[0]) for opening in narrative_openings):
+                        # Found character name + narrative opening
+                        potential_starts.append((i, 'character_name'))
+
+        # Check for strong narrative openings
+        for opening, needs_boundary in narrative_openings:
+            if lower.startswith(opening):
+                if needs_boundary:
+                    # Verify word boundary
+                    # If opening ends with space, next char can be anything (boundary already satisfied)
+                    # If opening doesn't end with space, next char must be boundary char
+                    if opening.endswith(' '):
+                        # Word boundary already in pattern (e.g., "the ", "when ")
+                        if len(stripped) > 15:
+                            potential_starts.append((i, f'opening:{opening[0]}'))
+                    else:
+                        # Need to check boundary (e.g., "it was" should not match "it wasn't")
+                        if len(stripped) == len(opening) or stripped[len(opening)] in ' .,;:!?':
+                            if len(stripped) > 15:
+                                potential_starts.append((i, f'opening:{opening[0]}'))
+                else:
+                    # Direct match OK
+                    if len(stripped) > 10:
+                        potential_starts.append((i, f'opening:{opening[0]}'))
+
+    # Return the EARLIEST match if we found any
+    if potential_starts:
+        # Sort by line number and return the first
+        potential_starts.sort(key=lambda x: x[0])
+        return potential_starts[0][0]
+
+    # Third priority: Remove OceanofPDF watermark sections
+    # These often appear between frontmatter and narrative
+    for i, line in enumerate(lines):
+        if 'oceanofpdf' in line.lower():
+            # Check if next few lines look like narrative
+            for j in range(i+1, min(i+10, len(lines))):
+                stripped = lines[j].strip()
+                if stripped and len(stripped) > 50 and stripped[0].isupper():
+                    # Found narrative after OceanofPDF marker
+                    return j
 
     # Fallback: Use keyword-based detection
     narrative_count = 0
@@ -435,6 +528,15 @@ def merge_broken_paragraphs(text):
             i += poetry_lines
             continue
 
+        # Check for play/script section
+        play_lines = patterns.detect_play_section(lines, i)
+        if play_lines > 0:
+            # Preserve play formatting (character names, stage directions, dialogue)
+            for j in range(i, min(i + play_lines, len(lines))):
+                result.append(lines[j].rstrip())
+            i += play_lines
+            continue
+
         # Check if we should merge with next line
         if i < len(lines) - 1:
             next_line = lines[i + 1].lstrip()
@@ -458,19 +560,22 @@ def merge_broken_paragraphs(text):
                 i += 1
                 continue
 
-            # Don't merge if current line is very short (likely intentional break)
-            if len(current) < 40:
-                result.append(current)
-                i += 1
-                continue
-
             # Merge if next line starts with lowercase or continuation punctuation
-            if next_line[0].islower() or next_line[0] in ',.;:)]}':
+            # This handles broken paragraphs like "the pain,\nchildish"
+            if next_line and (next_line[0].islower() or next_line[0] in ',.;:)]}'):
                 # Merge with space
                 result.append(current + ' ' + next_line)
                 i += 2
                 continue
 
+            # Don't merge if current line is very short (likely intentional break)
+            # BUT: moved this check AFTER the lowercase check so we still merge
+            # broken sentences even if the first part is short
+            if len(current) < 40:
+                result.append(current)
+                i += 1
+                continue
+
         # Default: keep line as-is
         result.append(current)
         i += 1
@@ -514,13 +619,61 @@ def find_backmatter_start(text):
         if estimated_end < len(lines):
             return min(int(estimated_end * 1.1), len(lines) - 1)
 
-    # Fallback: Use pattern matching in last 20% of document
-    search_start = max(0, int(len(lines) * 0.8))
+    # Fallback: Use pattern matching in last 30% of document
+    search_start = max(0, int(len(lines) * 0.7))
+
+    # First pass: Look for website watermarks and publisher markers (most reliable)
+    for i in range(search_start, len(lines)):
+        stripped = lines[i].strip().lower()
+
+        # Generic domain watermark detection (e.g., "oceanofpdf.com", "ebookbike.com", etc.)
+        # Matches: domain.com, www.domain.com, text.domain.com, or lines ending with .com/.net/.org
+        if patterns.DOMAIN_WATERMARK.search(stripped):
+            return i
+
+        # Also catch lines that contain ONLY a domain (possibly with spaces)
+        if stripped and '.' in stripped and len(stripped.split()) == 1:
+            # Check if it looks like a domain (has .com, .net, etc.)
+            if any(ext in stripped for ext in ['.com', '.net', '.org', '.io', '.co', '.uk', '.pdf']):
+                return i
+
+        # Publisher markers
+        if stripped == "publisher's note" or stripped == "publishers' note":
+            return i
+
+        # "About the Author" section
+        if stripped in ['about the author', 'about the authors']:
+            return i
+
+        # "Also by" / "More by" sections
+        if stripped.startswith('also by ') or stripped.startswith('more by '):
+            return i
+
+    # Second pass: Search backwards for backmatter keywords
     for i in range(len(lines) - 1, search_start, -1):
         stripped = lines[i].strip()
+        lower = stripped.lower()
+
+        # Check backmatter keywords
+        if any(kw in lower for kw in patterns.BACKMATTER_KEYWORDS):
+            # Make sure this isn't just a passing reference
+            # Check if it's a section header (short line, possibly all caps)
+            if len(stripped) < 100:
+                return i
+
+        # Check backmatter patterns
         for pattern in patterns.BACKMATTER_PATTERNS:
             if pattern.match(stripped):
                 return i
+
+    # Third pass: Look for all-caps section headers
+    for i in range(search_start, len(lines)):
+        stripped = lines[i].strip()
+        if stripped.isupper() and len(stripped) > 3 and len(stripped) < 100:
+            lower = stripped.lower()
+            if any(kw in lower for kw in ['afterword', 'about the author', 'acknowledgment', 'also by', 'more by']):
+                return i
+
     return None
 
 
